Module expansions

Module expansions 

Functions

absolute_with
Returns the path in its absolute form without resolving symlinks.
canonicalize_with
Resolve all symbolic links and all components (tilde, ., .., …+) and return the path in its absolute form.
expand_path
Resolve only path components (tilde, ., .., …+), if possible.
expand_path_with
Resolve only path components (tilde, ., .., …+), if possible.
expand_to_real_path
Resolve to a path that is accepted by the system and no further - tilde is expanded, and ndot path components are expanded.
locate_in_dirs
Attempts to canonicalize the path against the current directory. Failing that, if the path is relative, it attempts all of the dirs in dirs. If that fails, it returns the original error.