PathForm

Trait PathForm 

pub trait PathForm: Sealed { }
A marker trait for the different kinds of path forms. Each form has its own invariants that are guaranteed to be upheld. The list of path forms are:

  • Any: a path with no invariants. It may be a relative or an absolute path.
  • Relative: a strictly relative path.
  • Absolute: a strictly absolute path.
  • Canonical: a path that must be in canonicalized form.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors