PathPush

Trait PathPush 

pub trait PathPush: PathSet { }
A marker trait for PathForms that support pushing paths.

This includes only Any and Absolute path forms. Pushing onto a Relative path could cause it to become Absolute, which is why they do not support pushing. In the future, a push_rel and/or a try_push method could be added as an alternative. Similarly, Canonical paths may become uncanonical if a path is pushed onto it.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors